@@ -302,14 +302,26 @@ In case the service has been recently started please wait 5 minutes for it to be
             if self._debug:
                 print("Unexpected exception: ", ex)
 
-    def submit_job(self, *, backend=None, circuit=None, shots=None, comments=""):
+    def submit_job(self, *, backend=None, circuit=None, circuits=None, shots=None, comments=""):
         if not self._verify_user_is_authenticated():
             return
         if not backend:
             print("Please specify the backend name.")
             return
-        if not circuit:
-            print("The quantum circuit is missing.")
+        if circuit is None and circuits is None:
+            print("An quantum circuit to be executed or a list of quantum circuits to be executed must be specified.")
+            return
+        if circuit and circuits:
+            print("You can use either 'circuit' or 'circuits' as input arguments but not both at the same time.")
+            return
+        if circuit and not isinstance(circuit, QuantumCircuit):
+            print("The circuit must be an instance of QuantumCircuit.")
+            return
+        if circuits and not isinstance(circuits, list):
+            print("The circuits must be a list of QuantumCircuit instances.")
+            return
+        if circuits is not None and len(circuits) == 0:
+            print("The circuits list is empty.")
             return
         if shots is None:
             print("Please specify the number of shots.")
@@ -318,12 +330,22 @@ In case the service has been recently started please wait 5 minutes for it to be
             print("The number of shots must be specified as an integer number.")
             return
         try:
-            job_data = {
-                "BackendName": backend,
-                "Circuit": serialize_circuit(circuit),
-                "Shots": shots,
-                "Comments": comments,
-            }
+            if circuit:
+                job_data = {
+                    "BackendName": backend,
+                    "Circuit": serialize_circuit(circuit),
+                    "Circuits": [],
+                    "Shots": shots,
+                    "Comments": comments,
+                }
+            elif circuit:
+                job_data = {
+                    "BackendName": backend,
+                    "Circuit": None,
+                    "Circuits": [serialize_circuit(circuit) for circuit in circuits],
+                    "Shots": shots,
+                    "Comments": comments,
+                }
             (status_code, result) = self._make_post_request(
                 f"{self._asp_net_url}/api/job", job_data
             )
